MontyParameters

Trait MontyParameters 

pub trait MontyParameters:
    Copy
    + Default
    + Debug
    + Eq
    + PartialEq
    + Sync
    + Send
    + Hash
    + 'static {
    const PRIME: u32;
    const MONTY_BITS: u32;
    const MONTY_MU: u32;
    const MONTY_MASK: u32 = _;
}
MontyParameters contains the prime P along with constants needed to convert elements into and out of MONTY form. The MONTY constant is assumed to be a power of 2.

Required Associated Constants

Provided Associated Constants

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors